@@ -1,4 +1,5 @@
 from wechaty import FileBox, get_logger
+from wechaty.exceptions import WechatyOperationError
 from .contact import Contact
 from typing import Optional
 import asyncio
@@ -20,7 +21,7 @@ class ContactSelf(Contact):
             return file_box
 
         if self.contact_id != self.puppet.self_id():
-            raise Exception('set avatar only available for user self')
+            raise WechatyOperationError('set avatar only available for user self')
 
         await self.puppet.contact_avatar(self.contact_id, file)
 
@@ -29,36 +30,31 @@ class ContactSelf(Contact):
 
         :return:
         """
-        puppet_id: str
         try:
-            puppet_id = self.puppet.self_id()
+            puppet_id: str = self.puppet.self_id()
         except Exception as e:
-            raise Exception('Can not get qr_code, user might be either not logged in or already logged out')
+            raise WechatyOperationError('Can not get qr_code, user might be either not logged in or already logged out')
 
         if self.contact_id != puppet_id:
-            raise Exception('only can get qr_code for the login user self')
+            raise WechatyOperationError('only can get qr_code for the login user self')
         qr_code_value = await self.puppet.contact_self_qr_code()
         return qr_code_value
 
     @property
-    def name(self):
+    def name(self) -> str:
         """
-
         :return:
         """
+        return super().name
 
     @name.setter
-    def name(self, name: Optional[str]) -> str:
-        puppet_id: str
-        try:
-            puppet_id = self.puppet.self_id()
-        except Exception as e:
-            raise Exception('Can not get qr_code, user might be either not logged in or already logged out')
+    def name(self, name: Optional[str]):
+        puppet_id: str = self.puppet.self_id()
 
         if self.contact_id != puppet_id:
-            raise Exception('only can get qr_code for the login user self')
+            raise WechatyOperationError('only can get qr_code for the login user self')
 
-        return asyncio.run(self.puppet.contact_self_name(name))
+        asyncio.run(self.puppet.contact_self_name(name))
 
     async def signature(self, signature: str):
         """
@@ -66,13 +62,9 @@ class ContactSelf(Contact):
         :param signature:
         :return:
         """
-        puppet_id: str
-        try:
-            puppet_id = self.puppet.self_id()
-        except Exception as e:
-            raise Exception('Can not get qr_code, user might be either not logged in or already logged out')
+        puppet_id = self.puppet.self_id()
 
         if self.contact_id != puppet_id:
-            raise Exception('only can get qr_code for the login user self')
+            raise WechatyOperationError('only can get qr_code for the login user self')
 
         return self.puppet.contact_signature(signature)
