@@ -166,7 +166,8 @@ class Wechaty(AsyncIOEventEmitter):
 
         self._puppet: Optional[Puppet] = None
 
-        # Create watchdog on start, and allow to shutdown the watchdog by setting it to None
+        # Create watchdog on start, and allow to shutdown the watchdog by
+        # setting it to None
         self._watchdog: Optional[Watchdog] = None
         self._watchdog_task: Optional[asyncio.Task] = None
 
@@ -487,10 +488,18 @@ class Wechaty(AsyncIOEventEmitter):
                     friendship.contact().emit('friendship', friendship)
                     await self.on_friendship(friendship)
 
+                    await self._plugin_manager.emit_events(
+                        'friendship', friendship
+                    )
+
                 puppet.on('friendship', friendship_listener)
 
             elif event_name == 'login':
                 async def login_listener(payload: EventLoginPayload):
+
+                    # init the plugins
+                    await self._plugin_manager.init_plugins()
+
                     # set login contact_id
                     self.contact_id = payload.contact_id
                     log.info('receive <login> event <%s>', payload)
@@ -499,8 +508,8 @@ class Wechaty(AsyncIOEventEmitter):
                     self.emit('login', contact)
                     await self.on_login(contact)
 
-                    # init the plugins
-                    await self._plugin_manager.init_plugins()
+                    # emit the login event to plugins
+                    await self._plugin_manager.emit_events('login', contact)
 
                 puppet.on('login', login_listener)
 
@@ -513,6 +522,9 @@ class Wechaty(AsyncIOEventEmitter):
                     self.emit('logout', contact)
                     await self.on_logout(contact)
 
+                    # emit the logout event to plugins
+                    await self._plugin_manager.emit_events('logout', contact)
+
                 puppet.on('logout', logout_listener)
 
             elif event_name == 'message':
@@ -528,6 +540,7 @@ class Wechaty(AsyncIOEventEmitter):
                     if room is not None:
                         room.emit('message', room)
 
+                    # emit the message event to plugins
                     await self._plugin_manager.emit_events('message', msg)
 
                 puppet.on('message', message_listener)
@@ -549,6 +562,12 @@ class Wechaty(AsyncIOEventEmitter):
                     self.emit('room-invite', invitation)
                     await self.on_room_invite(invitation)
 
+                    # emit the room-invite event to plugins
+                    await self._plugin_manager.emit_events(
+                        'room-invite',
+                        invitation
+                    )
+
                 puppet.on('room-invite', room_invite_listener)
 
             elif event_name == 'room-join':
@@ -571,6 +590,12 @@ class Wechaty(AsyncIOEventEmitter):
 
                     room.emit('join', invitees, inviter, date)
 
+                    # emit the room-join event to plugins
+                    await self._plugin_manager.emit_events(
+                        'room-join', room,
+                        invitees, inviter, date
+                    )
+
                 puppet.on('room-join', room_join_listener)
 
             elif event_name == 'room-leave':
@@ -601,6 +626,11 @@ class Wechaty(AsyncIOEventEmitter):
                         # await self.puppet.room_member_payload_dirty(
                         #     payload.room_id)
 
+                    # emit the room-leave event to plugins
+                    await self._plugin_manager.emit_events(
+                        'room-leave', leavers, remover, date
+                    )
+
                 puppet.on('room-leave', room_leave_listener)
 
             elif event_name == 'room-topic':
@@ -623,6 +653,14 @@ class Wechaty(AsyncIOEventEmitter):
                     room.emit('topic', payload.new_topic, payload.old_topic,
                               changer, date)
 
+                    # emit the room-topic to plugins
+                    await self._plugin_manager.emit_events(
+                        'room-topic', room,
+                        payload.new_topic,
+                        payload.old_topic,
+                        changer, date
+                    )
+
                 puppet.on('room-topic', room_topic_listener)
 
             elif event_name == 'scan':
@@ -635,6 +673,12 @@ class Wechaty(AsyncIOEventEmitter):
                     self.emit('scan', payload.status, qr_code, payload.data)
                     await self.on_scan(payload.status, qr_code, payload.data)
 
+                    # emit the scan event to plugins
+                    await self._plugin_manager.emit_events(
+                        'scan', payload.status,
+                        qr_code, payload.data
+                    )
+
                 puppet.on('scan', scan_listener)
 
             elif event_name == 'reset':
